@@ -1,4 +1,4 @@
-## version: 1.31
+## version: 1.37
 ## method: get
 ## path: /configs/{id}
 ## code: 200
@@ -15,4 +15,5 @@ list(
     ## https://docs.docker.com/engine/api/v1.30/#operation/ConfigInspect
     ## the 'data' element is not returned, which is not consistent
     ## with the spec.
-    data = "VEhJUyBJUyBOT1QgQSBSRUFMIENFUlRJRklDQVRFCg=="))
+    data = "VEhJUyBJUyBOT1QgQSBSRUFMIENFUlRJRklDQVRFCg==",
+    templating = NULL))
